#include "xiicps.h"

XIicPs_Config XIicPs_ConfigTable[] __attribute__ ((section (".drvcfg_sec"))) = {

	{
		"cdns,i2c-r1p14", /* compatible */
		0xf1940000, /* reg */
		0x98961be, /* xlnx,clock-freq */
		0x4015, /* interrupts */
		0xe2000000, /* interrupt-parent */
		0x9d /* clocks */
	},
	{
		"cdns,i2c-r1p14", /* compatible */
		0xf1950000, /* reg */
		0x98961be, /* xlnx,clock-freq */
		0x4016, /* interrupts */
		0xe2000000, /* interrupt-parent */
		0x9f /* clocks */
	},
	 {
		 NULL
	}
};